package com.fxy.adapter;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.drawable.Drawable;
import android.os.Environment;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ProgressBar;
import android.widget.RadioButton;
import android.widget.RadioGroup;
import android.widget.TextView;
import android.widget.Toast;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.request.RequestOptions;
import com.elvishew.xlog.XLog;
import com.fxy.R;
import com.fxy.common.AudioRecoderDialog;
import com.fxy.utils.AudioRecoderUtils;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.StringUtils;

import java.io.File;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

import es.dmoral.toasty.Toasty;


public class ShowPictureAdapter extends RecyclerView.Adapter<ShowPictureAdapter.ViewHolder> {

    private LayoutInflater mInflater;
    //已上传
    private List<String> pictureList =new ArrayList<>();
    private int selectMax = 9;
    private  Context context;
    private  Activity mActivity;


    /**
     * 点击添加图片跳转
     */
    private final onAddPicClickListener mOnAddPicClickListener;

    public interface onAddPicClickListener {
        void onAddPicClick();
    }


    public ShowPictureAdapter(Context context, Activity activity, onAddPicClickListener mOnAddPicClickListener, List<String> list) {
        this.context = context;
        this.mActivity = activity;
        mInflater = LayoutInflater.from(context);
        this.mOnAddPicClickListener = mOnAddPicClickListener;
        pictureList= list;
    }

    public void setList( List<String> list) {
        this.pictureList = list;
    }

    /**
     *
     * 支持当前上传
     */
    public void setLocalMediaList(List<LocalMedia> list) {
        pictureList.clear();
        for (int i = 0; i < list.size(); i++) {
            String path;
            LocalMedia media= list.get(i);
            if (media.isCut() && !media.isCompressed()) {
                // 裁剪过
                path = media.getCutPath();
            } else if (media.isCompressed() || (media.isCut() && media.isCompressed())) {
                // 压缩过,或者裁剪同时压缩过,以最终压缩过图片为准
                path = media.getCompressPath();
            } else {
                // 原图
                path = media.getPath();
            }
            pictureList.add(path);
        }
    }

    public static class ViewHolder extends RecyclerView.ViewHolder {

        ImageView mImg;
        CheckBox cbSelect;
        View selectedOverlay;

        ViewHolder(View view) {
            super(view);
            mImg = view.findViewById(R.id.ivp_img);
            cbSelect = view.findViewById(R.id.cb_select);
            selectedOverlay = view.findViewById(R.id.selected_overlay);
        }
    }

    @Override
    public int getItemCount() {
        if (pictureList.size() < selectMax) {
            return pictureList.size() + 1;
        } else {
            return pictureList.size();
        }
    }


    /**
     * 创建ViewHolder
     */
    @Override
    public ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i) {
        View view = mInflater.inflate(R.layout.item_filter_image, viewGroup, false);
        return new ViewHolder(view);
    }
    /**
     * 设置值
     */
    @Override
    public void onBindViewHolder(final ViewHolder viewHolder, final int position) {
        //少于8张，显示继续添加的图标
        viewHolder.cbSelect.setVisibility(View.VISIBLE);
        viewHolder.cbSelect.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                // 当checkbox1的选中状态改变时执行
                if (isChecked) {
                    // checkbox1被选中了
                    viewHolder.selectedOverlay.setVisibility(View.VISIBLE);
                } else {
                    // checkbox1被取消了
                    viewHolder.selectedOverlay.setVisibility(View.GONE);
                }
            }
        });



        String path = pictureList.get(position);
        RequestOptions options = new RequestOptions()
                .centerCrop()
                .placeholder(R.color.color_f6)
                .diskCacheStrategy(DiskCacheStrategy.ALL);
        Glide.with(viewHolder.itemView.getContext())
                .load(path)
                .apply(options)
                .into(viewHolder.mImg);

        //itemView 的点击事件
        if (mItemClickListener != null) {
            viewHolder.itemView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    int adapterPosition = viewHolder.getAdapterPosition();
                    mItemClickListener.onItemClick(adapterPosition, v);
                }
            });
        }

    }

    private OnItemClickListener mItemClickListener;

    public interface OnItemClickListener {
        void onItemClick(int position, View v);
    }

    public void setOnItemClickListener(OnItemClickListener listener) {
        this.mItemClickListener = listener;
    }
}